@@ -1,14 +1,13 @@
 import sys
 
-from lmfit import Parameters, Parameter, Minimizer
+from lmfit import Parameters, Parameter, Minimizer, report_fit
 from lmfit.utilfuncs import gauss, loren, pvoigt
 
 from numpy import linspace, zeros, sin, exp, random, sqrt, pi, sign
-from testutils import report_errors
 
 try:
     import matplotlib
-    matplotlib.use('WXAGG')
+    # matplotlib.use('WXAGG')
     import pylab
     HASPYLAB = True
 except ImportError:
@@ -86,7 +85,7 @@ myfit.leastsq()
 print(' Nfev = ', myfit.nfev)
 print( myfit.chisqr, myfit.redchi, myfit.nfree)
 
-report_errors(myfit.params, modelpars=p_true)
+report_fit(myfit.params, modelpars=p_true)
 
 fit = residual(myfit.params, x)
 
