@@ -1,5 +1,5 @@
 
-from lmfit import minimize, Parameters, Parameter, report_errors
+from lmfit import minimize, Parameters, Parameter, report_fit
 import numpy as np
 
 # create data to be fitted
@@ -14,14 +14,14 @@ def fcn2min(params, x, data):
     shift = params['shift'].value
     omega = params['omega'].value
     decay = params['decay'].value
-    
+
     model = amp * np.sin(x * omega + shift) * np.exp(-x*x*decay)
     return model - data
 
 # create a set of Parameters
 params = Parameters()
 params.add('amp',   value= 10,  min=0)
-params.add('decay', value= 0.1) 
+params.add('decay', value= 0.1)
 params.add('shift', value= 0.0, min=-np.pi/2., max=np.pi/2)
 params.add('omega', value= 3.0)
 
@@ -33,7 +33,7 @@ result = minimize(fcn2min, params, args=(x, data))
 final = data + result.residual
 
 # write error report
-report_errors(params)
+report_fit(params)
 
 # try to plot results
 try:
